==> kvpnc-trinity_14.0.5.orig.tar.xz: kvpnc-trinity-14.0.5/src/profilecmdexecafterdisconnectoptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "profilecmdexecafterdisconnectoptions.h"

#include <tqcheckbox.h>
#include <ktextedit.h>
#include "widgetnotifyhelper.h"
#include <iostream>



ProfileCmdExecAfterDisconnectOptions::ProfileCmdExecAfterDisconnectOptions(TQWidget *parent)
		: ProfileCmdExecAfterDisconnectOptionsBase(parent)
{
	WidgetNotifyHelper h;
	h.setupChangedAction(this);
	dialogModified=false;
}


ProfileCmdExecAfterDisconnectOptions::~ProfileCmdExecAfterDisconnectOptions()
{}

void ProfileCmdExecAfterDisconnectOptions::execCmdAfterDisconnectToggled(bool)
{
	if (ExcuteCmdAfterDisconnectCheckBox->isChecked())
		CmdAfterDisconnectTextEdit->setEnabled( TRUE );
	else
		CmdAfterDisconnectTextEdit->setEnabled( FALSE );
}

void ProfileCmdExecAfterDisconnectOptions::dialogChanged()
{
	std::cout << "ProfileCmdExecAfterDisconnectOptions::dialogChanged()" << std::endl;
	dialogModified=true;
}

==> kvpnc-trinity_14.1.6~pre2.orig.tar.xz: kvpnc-trinity-14.1.6~pre2+b555b77b/src/profilecmdexecafterdisconnectoptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "profilecmdexecafterdisconnectoptions.h"

#include <tqcheckbox.h>
#include <ktextedit.h>
#include "widgetnotifyhelper.h"
#include <iostream>



ProfileCmdExecAfterDisconnectOptions::ProfileCmdExecAfterDisconnectOptions(TQWidget *parent)
		: ProfileCmdExecAfterDisconnectOptionsBase(parent)
{
	WidgetNotifyHelper h;
	h.setupChangedAction(this);
	dialogModified=false;
}


ProfileCmdExecAfterDisconnectOptions::~ProfileCmdExecAfterDisconnectOptions()
{}

void ProfileCmdExecAfterDisconnectOptions::execCmdAfterDisconnectToggled(bool)
{
	if (ExcuteCmdAfterDisconnectCheckBox->isChecked())
		CmdAfterDisconnectTextEdit->setEnabled( true );
	else
		CmdAfterDisconnectTextEdit->setEnabled( false );
}

void ProfileCmdExecAfterDisconnectOptions::dialogChanged()
{
	std::cout << "ProfileCmdExecAfterDisconnectOptions::dialogChanged()" << std::endl;
	dialogModified=true;
}

#include "profilecmdexecafterdisconnectoptions.moc"
